package net.sf.itcb.module.blank.server;


import javax.annotation.Resource;

import net.sf.itcb.module.blank.business.service.BlankService;
import net.sf.itcb.module.blank.schemas.GetAllBlanksRequest;
import net.sf.itcb.module.blank.schemas.GetAllBlanksResponse;
import net.sf.itcb.module.blank.schemas.GetBlankRequest;
import net.sf.itcb.module.blank.schemas.GetBlankResponse;
import net.sf.itcb.module.blank.schemas.SaveBlankRequest;
import net.sf.itcb.module.blank.schemas.SaveBlankResponse;
import net.sf.itcb.module.blank.schemas.UpdateManyBlanksRequest;
import net.sf.itcb.module.blank.schemas.UpdateManyBlanksResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Configurable;
import org.springframework.ws.server.endpoint.annotation.Endpoint;
import org.springframework.ws.server.endpoint.annotation.PayloadRoot;

/**
 * Service implementation example.<br/>
 * Resources and dao are injected by Spring annotations.<br/>
 * No technical exception management (thrown by dafault to the upper level).<br/>
 * Only functional exception management.<br/>
 * No commit / No rollback. Transation manager does it by spring declaration.<br/>
 * 
 * The service implementation extends the service BlankService (inside blank-business module).
 * 
 * @author Pierre Le Roux
 */
@Endpoint
@Configurable(preConstruction = true)
public class BlankServiceServer implements BlankService {

	@Resource(name="blankService")
	BlankService blankService;
	
	protected final Logger log = LoggerFactory.getLogger(getClass());
	
	@Override
	@PayloadRoot(localPart= "getBlankRequest", namespace="http://blank.module.itcb.sf.net/schemas")
	public GetBlankResponse getBlankById(GetBlankRequest getBlankRequest) throws Exception {
		return blankService.getBlankById(getBlankRequest);
	}
	
	@Override
	@PayloadRoot(localPart= "saveBlankRequest", namespace="http://blank.module.itcb.sf.net/schemas")
	public SaveBlankResponse saveBlank(SaveBlankRequest saveBlankRequest) throws Exception  {
		return blankService.saveBlank(saveBlankRequest);
	}
	
	@Override
	@PayloadRoot(localPart= "updateManyBlanksRequest", namespace="http://blank.module.itcb.sf.net/schemas")
	public UpdateManyBlanksResponse updateManyBlanks(UpdateManyBlanksRequest updateManyBlanksRequest) throws Exception {
		return blankService.updateManyBlanks(updateManyBlanksRequest);
	}

	@Override
	@PayloadRoot(localPart= "getAllBlanksRequest", namespace="http://blank.module.itcb.sf.net/schemas")
	public GetAllBlanksResponse getAllBlanks(GetAllBlanksRequest getAllBlanksRequest) throws Exception {
		return blankService.getAllBlanks(getAllBlanksRequest);
	}
	
}

